.. yaqc-cmds documentation master file, created by
   sphinx-quickstart on Mon Oct 12 18:47:33 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

yaqc-cmds
=========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   autonomic

.. raw:: html

   <iframe width="560" height="315" src="https://www.youtube.com/embed/FpfVqoIRadA" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
